<?php

/**
 * @file
 * Definition of Drupal\photos\PhotosEditController.
 */

namespace Drupal\photos\Controller;

use Drupal\Core\Url;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\Routing\Route;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class PhotosEditController {

  /**
   * A custom access check.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   */
  public function access(AccountInterface $account) {
    // Check for available parameters.
    $nid = \Drupal::routeMatch()->getParameter('node');
    $fid = \Drupal::routeMatch()->getParameter('file');
    if ($nid && $fid) {
      // Update cover.
      $node = \Drupal\node\Entity\Node::load($nid);
      if (_photos_access('editAlbum', $node)) {
        // Allowed to update album cover image.
        return AccessResult::allowed();
      }
      else {
        // Deny access.
        return AccessResult::forbidden();
      }
    }
    elseif ($fid) {
      // Check if edit or delete.
      $current_path = \Drupal::service('path.current')->getPath();
      $path_args = explode('/', $current_path);
      if (isset($path_args[4])) {
        if ($path_args[4] == 'edit' || $path_args[4] == 'to_sub') {
          if (_photos_access('imageEdit', $fid)) {
            // Allowed to edit image.
            return AccessResult::allowed();
          }
        }
        elseif ($path_args[4] == 'delete') {
          if (_photos_access('imageDelete', $fid)) {
            // Allowed to delete image.
            return AccessResult::allowed();
          }
        }
      }
      // Deny access.
      return AccessResult::forbidden();
    }
    else {
      return AccessResult::neutral();
    }
  }

  /**
   * Edit image.
   */
  public function editImage($file) {
    $fid = $file;
    $output = '';
    $images = array();
    $query = db_select('file_managed', 'f');
    $query->join('photos_image', 'p', 'p.fid = f.fid');
    $query->join('users_field_data', 'u', 'f.uid = u.uid');
    $query->fields('f', array('uri', 'filemime', 'created', 'filename', 'filesize'));
    $query->fields('p');
    $query->fields('u', array('uid', 'name'));
    $query->condition('f.fid', $fid);
    $result = $query->execute();

    foreach ($result as $data) {
      $images[] = photos_get_info(0, $data);
    }

    if (isset($images[0]->fid)) {
      $node = \Drupal::entityManager()->getStorage('node')->load($images[0]->pid);
      $images[0]->info = array(
        'cover' => $node->album['cover'],
        'pid' => $node->id(),
        'title' => $node->getTitle(),
        'uid' => $node->uid
      );
      $edit_form = \Drupal::formBuilder()->getForm('\Drupal\photos\Form\PhotosImageEditForm', $images);
      // $output = \Drupal::service("renderer")->render($edit_form);
    }

    return $edit_form;
  }

  /**
   * Delete image from gallery and site.
   */
  public function deleteImage($file) {
    $fid = $file;
    if (\Drupal::moduleHandler()->moduleExists('colorbox')) {
      // Dispaly form in modal popup.
      // @todo does this still work?
      $confirm_delete_form = \Drupal::formBuilder()->getForm('\Drupal\photos\Form\PhotosImageConfirmDeleteForm', $fid);
      print \Drupal::service("renderer")->render($confirm_delete_form);
    }
    else {
      // Render full page.
      return \Drupal::formBuilder()->getForm('\Drupal\photos\Form\PhotosImageConfirmDeleteForm', $fid);
    }
  }

  /**
   * Set album cover.
   */
  public function setAlbumCover($node, $file) {
    $pid = db_query('SELECT pid FROM {photos_image} WHERE fid = :fid', array(':fid' => $file))->fetchField();
    if ($pid == $node) {
      // Update cover.
      db_query('UPDATE {photos_album} SET fid = :fid WHERE pid = :pid',
        array(':fid' => $file, ':pid' => $node));
      // Clear node cache.
      Cache::invalidateTags(array('node:' . $node));
      drupal_set_message(t('Cover successfully set.'));
      $goto = isset($_GET['destination']) ? $_GET['destination'] : 'photos/album/' . $node;
      $goto = Url::fromUri('base:' . $goto)->toString();
      $response = new RedirectResponse($goto);
      $response->send();
      return array(
        '#markup' => t('Cover successfully set.')
      );
    }
    else {
      throw new NotFoundHttpException();
    }
  }

  /**
   * Add image to sub album.
   */
  public function addImageSubAlbum($file) {
    $user = \Drupal::currentUser();
    // @todo update form and test (\Drupal\photos\Form\PhotosImageSubAlbumForm).
    $photos_to_sub_form = \Drupal::formBuilder()->getForm('\Drupal\photos\Form\PhotosImageSubAlbumForm', $file);
    $content = \Drupal::service("renderer")->render($photos_to_sub_form);
    $content .= drupal_render(array('#type' => 'pager'));

    $render_array = array(
      '#theme' => 'photos_print',
      '#content' => $content
    );

    print drupal_render($render_array);
  }

}
