<?php

/**
 * @file
 * Contains \Drupal\photos\Form\PhotosImageEditForm.
 */

namespace Drupal\photos\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;

/**
 * Defines a form to edit images.
 */
class PhotosImageEditForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'photos_image_edit';
  }

  /**
   * Get album images by $node->id().
   * @todo move function so it is easily accessible.
   */
  public function getAlbumImages($nid, $limit = 10) {
    $images = array();
    $column = isset($_GET['field']) ? $_GET['field'] : '';
    $sort = isset($_GET['sort']) ? $_GET['sort'] : '';
    $term = _photos_order_value($column, $sort, $limit, array('column' => 'p.wid', 'sort' => 'asc'));
    $query = db_select('file_managed', 'f')
      ->extend('Drupal\Core\Database\Query\PagerSelectExtender');
    $query->join('photos_image', 'p', 'p.fid = f.fid');
    $query->join('users_field_data', 'u', 'f.uid = u.uid');
    $query->join('node', 'n', 'n.nid = p.pid');
    $query->fields('f', array('uri', 'filemime', 'created', 'filename', 'filesize'));
    $query->fields('p');
    $query->fields('u', array('uid', 'name'));
    $query->condition('p.pid', $nid);
    $query->limit($term['limit']);
    $query->orderBy($term['order']['column'], $term['order']['sort']);
    $query->addTag('node_access');
    $result = $query->execute();
    foreach ($result as $data) {
      // @todo create new function to return image object.
      $images[] = photos_get_info(0, $data);
    }
    if (isset($images[0]->fid)) {
      $node = \Drupal::entityManager()->getStorage('node')->load($nid);
      $images[0]->info = array(
        'pid' => $node->id(),
        'title' => $node->getTitle(),
        'uid' => $node->getOwnerId()
      );
      if (isset($node->album['cover'])) {
        $images[0]->info['cover'] = $node->album['cover'];
      }
    }
    return $images;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $images = array(), $type = 'album') {
    //$args = $form_state->getBuildInfo()['args'][0];
    //drupal_set_message(print_r($args, 1));
    $user = \Drupal::currentUser();

    if (empty($images)) {
      $nid = \Drupal::routeMatch()->getParameter('node');
    }
    else {
      if (isset($images[0]->info['nid'])) {
        $nid = $images[0]->info['nid'];
      }
      else {
        $nid = $images[0]->info['pid'];
      }
    }

    // Get node object.
    $node = \Drupal\node\Entity\Node::load($nid);
    // @todo get type (album or sub-album).
    if ($type == 'album') {
      $album_update = '';
      if (isset($images[0]) && $user->id() <> $images[0]->info['uid']) {
        $title = isset($images[0]->info['title']) ? $images[0]->info['title'] : '';
        $album_update = array($nid, $images[0]->info['title']);
      }
      else {
        $album_update = '';
      }
      $uid = isset($images[0]) ? $images[0]->uid : $user->id();
      $album_pid = _photos_useralbum_option($uid, $album_update);
      $del_label = t('Delete');
      if (isset($images[0]->fid)) {
        $form['cover_fid'] = array('#type' => 'hidden', '#default_value' => $images[0]->fid);
      }
      $form['oldpid'] = array('#type' => 'hidden', '#default_value' => $nid);
      $submit = 'photos_editlist_submit';
    }
    else {
      //
      $del_label = t('Move out');
      $submit = 'photos_editlist_submit_node';
      $form['nid'] = array('#type' => 'hidden', '#default_value' => $nid);
    }
    $form['photos']['#tree'] = TRUE;
    foreach ($images as $image) {
      $form['photos'][$image->fid]['del'] = array(
        '#title' => $del_label. ' ',
        '#type' => 'checkbox',
        '#prefix' => '<div class="edit-del-all">',
        '#suffix' => '</div>'
      );
      $image->user = \Drupal::entityManager()->getStorage('user')->load($image->uid);
      $image->href = 'photos/image/' . $image->fid;
      $item = array();
      $title = $image->title;
      $style_name = \Drupal::config('photos.settings')->get('photos_size_0');
      $image_view = array(
        '#theme' => 'image_style',
        '#style_name' => $style_name,
        '#uri' => $image->uri,
        '#width' => $image->width,
        '#height' => $image->height,
        '#alt' => $title,
        '#title' => $title
      );

      $item[] = \Drupal::l($image_view, Url::fromUri('base:' . $image->href), array(
        'html' => TRUE,
        'attributes' => array('title' => $title)
      ));

      if ($type == 'album' && $images[0]->fid <> $image->fid) {
        // Set cover link.
        $cover_url = Url::fromRoute('photos.album.update.cover', array(
          'node' => $image->pid,
          'file' => $image->fid
        ));
        $item[] = \Drupal::l(t('Set to Cover'), $cover_url);
      }
      if (isset($image->filesize)) {
        // @todo update to use MB?
        $size = round($image->filesize/1024);
        $item[] = t('Filesize: @size KB', array('@size' => number_format($size)));
      }
      if (isset($image->count)) {
        $item[] = t('Visits: @count', array('@count' => $image->count));
      }
      if (isset($image->comcount)) {
        $item[] = t('Comments: @count', array('@count' => $image->comcount));
      }
      $form['photos'][$image->fid]['path'] = array(
        '#theme' => 'item_list',
        '#items' => $item
      );
      $form['photos'][$image->fid]['des'] = array(
        '#title' => t('Image description'),
        '#type' => 'textarea',
        '#default_value' => isset($image->des) ? $image->des : '',
        '#cols' => 40,
        '#rows' => 4
      );
      $form['photos'][$image->fid]['title'] = array(
        '#title' => t('Image title'),
        '#type' => 'textfield',
        '#default_value' => isset($image->title) ? $image->title : '',
        '#required' => FALSE
      );
      $form['photos'][$image->fid]['wid'] = array(
        '#title' => t('Weight'),
        '#type' => 'textfield',
        '#size' => 5,
        '#default_value' => isset($image->wid) ? $image->wid : NULL,
      );
      $form['photos'][$image->fid]['filepath'] = array('#type' => 'value', '#value' => $image->uri);
      if ($type == 'album') {
        $username = array(
          '#theme' => 'username',
          '#account' => $image->user
        );
        $upload_info = t('Uploaded on @time by @name', array(
          '@name' => drupal_render($username),
          '@time' => format_date($image->created, 'small')
        ));
        $form['photos'][$image->fid]['pid'] = array(
          '#title' => t('Move to the album'),
          '#type' => 'select',
          '#options' => $album_pid,
          '#default_value' => $image->pid,
          '#required' => TRUE
        );
      }
      else {
        $upload_info = t('Uploaded by @name on @time to @title', array(
          '@name' => array(
            '#theme' => 'username',
            '#account' => $image->user
          ),
          '@time' => format_date($image->created, 'small'),
          '@title' => \Drupal::l($image->album_title, Url::fromUri('base:node/' . $image->pid))
        ));
      }
      $form['photos'][$image->fid]['time']['#markup'] = $upload_info;
      $form['photos'][$image->fid]['uid'] = array('#type' => 'hidden', '#default_value' => $image->uid);
      $form['photos'][$image->fid]['oldtitle'] = array('#type' => 'hidden', '#default_value' => $image->title);
    };
    if (!empty($images)) {
      $form['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Confirm changes')
      );
    }

    return $form;
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {
    // ...
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    foreach ($form_state->getValue('photos') as $fid => $key) {
      if (!empty($key['del'])) {
        if ($form_state->getValue('cover_fid') == $fid) {
          db_update('photos_album')
            ->fields(array(
              'fid' => 0
            ))
            ->condition('pid', $form_state->getValue('oldpid'))
            ->execute();
        }
        $msg[] = photos_file_del($fid, $key['filepath']);
        $uids[] = $key['uid'];
      }
      else {
        db_update('photos_image')
          ->fields(array(
            'pid' => $key['pid'],
            'des' => $key['des'],
            'wid' => $key['wid']
          ))
          ->condition('fid', $fid)
          ->execute();

        if ($key['title'] <> $key['oldtitle']) {
          db_update('photos_image')
            ->fields(array(
              'title' => $key['title']
            ))
            ->condition('fid', $fid)
            ->execute();
        }
        if ($key['pid'] <> $form_state->getValue('oldpid')) {
          $sub_select = db_select('photos_comment', 'v')
            ->fields('v', array('cid'))
            ->condition('v.fid', $fid)
            ->execute()->fetchCol();
          if (!empty($sub_select)) {
            db_update('comment')
              ->fields(array(
                'nid' => $key['pid']
              ))
              ->condition('cid', $sub_select, 'IN')
              ->execute();
          }
          $pid[] = $key['pid'];
          $uids[] = $key['uid'];
        }
      }
    }
    if (isset($msg)) {
      $pid[] = $form_state->getValue('oldpid');
      // @todo plural for 1 image.
      drupal_set_message(t('@count images deleted.', array('@count' => count($msg))));
    }
    if (isset($pid) && count($pid)) {
      foreach ($pid as $nid) {
        // Get node object and update comment statistics.
        // @todo Argument 1 passed to Drupal\comment\CommentStatistics::update() must be an instance of Drupal\comment\CommentInterface.
        // $node = \Drupal\node\Entity\Node::load($nid);
        // \Drupal::service('comment.statistics')->update($node);
        photos_set_count('node_album', $nid);
      }
      $uid = array_unique($uids);
      foreach ($uid as $id) {
        photos_set_count('user_image', $id);
      }
    }


  // @todo check and implement the following for sub-albums.
  /*
    foreach ($form_state->getValue('photos') as $fid => $key) {
     if (!empty($key['del'])) {
       $msg[] = db_query('DELETE FROM {photos_node} WHERE fid = :fid AND nid = :nid',
         array(':fid' => $fid, ':nid' => $form_state->getValue('nid')));
     }
     else {
       $update_fields = array(
         'des' => $key['des'],
       );
       if ($key['title'] <> $key['oldtitle']) {
         $update_fields['title'] = $key['title'];
       }
       db_merge('photos_image')
         ->key(array(
           'fid' => $fid
         ))
         ->fields($update_fields)
         ->execute();
       if ($key['wid']) {
         db_update('photos_node')
           ->fields(array(
             'wid' => $key['wid']
           ))
           ->condition('fid', $fid)
           ->condition('nid', $form_state->getValue('nid'))
           ->execute();
       }
     }
   }
   if (isset($msg)) {
     photos_set_count('node_node', $form_state->getValue('nid'));
     drupal_set_message(t('@count images are move out.', array('@count' => count($msg))));
   }
   */

  }

}
